@@ -132,7 +132,7 @@ sub read {
             push @license_names, $lic_name ;
         }
         else {
-            my $str = "Unknow section type beginning at line $section_line. "
+            my $str = "Unknown section type beginning at line $section_line. "
                 . "Is it a Files or a License section ?";
             if ($check eq 'yes') {
                 Config::Model::Exception::Syntax -> throw ( 
