@@ -207,12 +207,13 @@ in ‘/usr/share/common-licenses/GPL-1’.",
     },
     {
         name => 'oar',
-        load_warnings => [ qr/use Expat/ ],
+        load_warnings => [ qr/Format does not match/, qr/use Expat/ ],
         no_warnings => 1,
+        apply_fix => 1,
 
         check => {
-            'Files:"sources/extra/orpheus/modules/lua-signal/lsignal.c" License short_name'
-            => 'MIT'
+            Format => "https://www.debian.org/doc/packaging-manuals/copyright-format/1.0/",
+            'Files:"sources/extra/orpheus/modules/lua-signal/lsignal.c" License short_name' => 'Expat'
         }
     },
     {
